==> deepin-log-viewer_5.9.3.orig.tar.xz: deepin-log-viewer-5.9.3/translations/deepin-log-viewer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Limpiar registro</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>¿Está seguro de desea limpiar el registro?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportar</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depurar</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Supercrítico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportando...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportación exitosa</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportar fallós</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar archivo</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periodo:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista de aplicaciones:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registro de arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registro de apagado</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registro de inicio de sesión</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depurar</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Supercrítico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El archivo de registro está vacío</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registros</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Visor de registros de Deepin es una herramienta que facilita examinar los registros del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hay resultados de búsqueda</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proceso</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Fecha y hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proceso:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Fecha y hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Información:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Fecha y hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registro del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registro del kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registro de arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registro de dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registro de cambios de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registro Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registro de aplicación</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Evento arranque-apagado</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registro dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Limpiar registro</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>¿Está seguro de desea limpiar el registro?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportar</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depurar</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Supercrítico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportando...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportación exitosa</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportar fallós</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar archivo</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periodo:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista de aplicaciones:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registro de arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registro de apagado</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registro de inicio de sesión</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depurar</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Supercrítico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El archivo de registro está vacío</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registros</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Visor de registros de Deepin es una herramienta que facilita examinar los registros del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hay resultados de búsqueda</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proceso</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Fecha y hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proceso:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Fecha y hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Información:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Fecha y hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registro del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registro del kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registro de arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registro de dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registro de cambios de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registro Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registro de aplicación</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Evento arranque-apagado</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registro dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Intervalo de actualización</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 s</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 m</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sin actualizar</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exportar todo</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Registros del sistema</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Actualizar ahora</translation>
    </message>
</context>
</TS>
